package org.bitbucket.bradleysmithllc.etlunit.feature.database.db;

import org.bitbucket.bradleysmithllc.etlunit.util.StringUtils;

import java.util.*;

public class SchemaImpl implements Schema
{
	private final String name;
	private final Catalog catalog;

	private final List<Table> tableList = new ArrayList<Table>();
	private final Map<String, Table> tableMap = new HashMap<String, Table>();

	public SchemaImpl(Catalog catalog, String name) {
		this.name = name;
		this.catalog = catalog;
	}

	@Override
	public String getName() {
		return name;
	}

	@Override
	public List<Table> getTables() {
		return Collections.unmodifiableList(tableList);
	}

	@Override
	public Map<String, Table> getTableMap() {
		return tableMap;
	}

	@Override
	public Table getTable(String name) {
		return tableMap.get(StringUtils.getSafeNullableUppercase(name));
	}

	public void addTable(Table table)
	{
		tableList.add(table);
		tableMap.put(StringUtils.getSafeNullableUppercase(table.getName()), table);
	}

	public String toString()
	{
		return (catalog == null ? "" : (catalog.toString() + ".")) + (name == null ? "[DEFAULT]" : name);
	}
}